aboutsummaryrefslogtreecommitdiffstats
path: root/src/net/java/sip/communicator/service
diff options
context:
space:
mode:
authorRomain Kuntz <rkuntz@java.net>2008-10-06 10:38:30 +0000
committerRomain Kuntz <rkuntz@java.net>2008-10-06 10:38:30 +0000
commit5e3ce7bb175bbd3493538d4e90020d42e6da1250 (patch)
tree4af900db1dcc36d0e378fde4fb5b4201ad9b85e6 /src/net/java/sip/communicator/service
parentb0f7b08de63660a439954a7409982e53fc58c114 (diff)
downloadjitsi-5e3ce7bb175bbd3493538d4e90020d42e6da1250.zip
jitsi-5e3ce7bb175bbd3493538d4e90020d42e6da1250.tar.gz
jitsi-5e3ce7bb175bbd3493538d4e90020d42e6da1250.tar.bz2
Added ZRTP4J bundle
Added the boucycastle lib Renamed OperationSetSecuredTelephony to OperationSetSecureTelephony Renamed the isSecured/setSecured method to isSecure/setSecure Fixed some identations
Diffstat (limited to 'src/net/java/sip/communicator/service')
-rw-r--r--src/net/java/sip/communicator/service/media/CallSession.java2
-rw-r--r--src/net/java/sip/communicator/service/protocol/OperationSetSecureTelephony.java (renamed from src/net/java/sip/communicator/service/protocol/OperationSetSecuredTelephony.java)12
-rw-r--r--src/net/java/sip/communicator/service/protocol/SecureEvent.java6
3 files changed, 10 insertions, 10 deletions
diff --git a/src/net/java/sip/communicator/service/media/CallSession.java b/src/net/java/sip/communicator/service/media/CallSession.java
index 6346f5b..67f68549 100644
--- a/src/net/java/sip/communicator/service/media/CallSession.java
+++ b/src/net/java/sip/communicator/service/media/CallSession.java
@@ -200,7 +200,7 @@ public interface CallSession
* @param source the initiator of the secure status change (can be local or remote)
*/
public void setSecureCommunicationStatus(boolean activator,
- OperationSetSecuredTelephony.
+ OperationSetSecureTelephony.
SecureStatusChangeSource source);
/**
diff --git a/src/net/java/sip/communicator/service/protocol/SecureEvent.java b/src/net/java/sip/communicator/service/protocol/SecureEvent.java
index 82b5299..8dc4b84 100644
--- a/src/net/java/sip/communicator/service/protocol/SecureEvent.java
+++ b/src/net/java/sip/communicator/service/protocol/SecureEvent.java
@@ -41,7 +41,7 @@ public class SecureEvent
/**
* The source that triggered the event - local or remote peer
*/
- private OperationSetSecuredTelephony.SecureStatusChangeSource source;
+ private OperationSetSecureTelephony.SecureStatusChangeSource source;
/**
* The event constructor
@@ -51,7 +51,7 @@ public class SecureEvent
*/
public SecureEvent(CallSessionImpl callSession,
int eventID,
- OperationSetSecuredTelephony.SecureStatusChangeSource source)
+ OperationSetSecureTelephony.SecureStatusChangeSource source)
{
super(callSession);
this.eventID = eventID;
@@ -72,7 +72,7 @@ public class SecureEvent
* Retrieves the source that triggered the event
* (change by local peer or remote peer or reverting a previous change)
*/
- public OperationSetSecuredTelephony.SecureStatusChangeSource getSource()
+ public OperationSetSecureTelephony.SecureStatusChangeSource getSource()
{
return source;
}
diff --git a/src/net/java/sip/communicator/service/protocol/OperationSetSecuredTelephony.java b/src/net/java/sip/communicator/service/protocol/OperationSetSecureTelephony.java
index faf6033..b1801ed 100644
--- a/src/net/java/sip/communicator/service/protocol/OperationSetSecuredTelephony.java
+++ b/src/net/java/sip/communicator/service/protocol/OperationSetSecureTelephony.java
@@ -14,29 +14,29 @@ import net.java.sip.communicator.service.protocol.event.*;
* @author Emanuel Onica
* @author Romain Kuntz
*/
-public interface OperationSetSecuredTelephony
+public interface OperationSetSecureTelephony
extends OperationSet
{
/**
* Sets the secured state of the call session in which a specific participant
* is involved
*
* @param participant the participant who toggled (or for whom is remotely
* toggled) the secure status change for the call
- * @param secured the new secure status
+ * @param secure the new secure status
* @param source the source who generated the call change
*/
- public void setSecured(CallParticipant participant, boolean secured,
+ public void setSecure(CallParticipant participant, boolean secure,
SecureStatusChangeSource source);
/**
* Gets the secured state of the call session in which a specific participant
* is involved
*
* @param participant the participant for who the call state is required
* @return the call state
*/
- public boolean isSecured(CallParticipant participant);
+ public boolean isSecure(CallParticipant participant);
/**
* Use this to indicate the source of setting the secure status
@@ -14,29 +14,29 @@ import net.java.sip.communicator.service.protocol.event.*;
{
/**
- * Sets the secured state of the call session in which a specific participant
+ * Sets the secure state of the call session in which a specific participant
* is involved
*
@@ -14,29 +14,29 @@ import net.java.sip.communicator.service.protocol.event.*;
SecureStatusChangeSource source);
/**
- * Gets the secured state of the call session in which a specific participant
+ * Gets the secure state of the call session in which a specific participant
* is involved
*